@@ -354,7 +354,7 @@ AuDeviceAttributes(const unsigned char *buf)
     int l;
 
     printfield(buf, 0, 4, CARD32, "value mask");
-    printfield(buf, 4, 4, CARD32, "changable mask");
+    printfield(buf, 4, 4, CARD32, "changeable mask");
     printfield(buf, 8, 4, CARD32, "id");
     printfield(buf, 12, 1, CARD8, "kind");
     printfield(buf, 13, 1, CARD8, "use");
