@@ -658,20 +658,25 @@ static void _X_NORETURN
 Usage(void)
 {
     fprintf(stderr,
-            "Usage: xscope\n"
-            "              [-h<server-host>]\n"
-            "              [-i<in-port>]\n"
-            "              [-o<out-port>]\n"
-            "              [-d<display-number>]\n"
-            "              [-v<n>]  -- verbose output\n"
-            "              [-r]  -- raw output\n"
-            "              [-a<n>]  -- audio verbose output\n"
-            "              [-q]  -- quiet output\n"
-            "              [-D<debug-level>]\n"
-            "              [-I]  -- start in interactive mode\n"
-            "              [-S<n>] -- start/stop on SIGUSR1\n"
-            "              [-V]  -- output version information and exit\n"
-            "              [-t]  -- terminate when all clients close\n");
+            "Usage: xscope [options]\n"
+            "Options:\n"
+            "  -i<in-port>         Port used to take requests from clients\n"
+            "  -o<out-port>        Port used to connect to X11\n"
+            "  -h<server-host>     Determines the host used to find its X11 server\n"
+            "  -d<display-number>  Defines the display number\n"
+            "  -f<filename>        Reads previously captured raw data from a file\n"
+            "  -I                  Start in interactive mode\n"
+            "  -S<n>               Start/stop on SIGUSR1 (0/1)\n"
+            "  -T                  Transposes some output with an offset of 0x20\n"
+            "  -A                  Enables Network Audio System (NAS) support\n"
+            "  -a<level>           Audio verbose output\n"
+            "  -n<server-host>     NAS server to connect to\n"
+            "  -D<level>           Debug level (default = 255)\n"
+            "  -q                  Quiet output\n"
+            "  -r                  Raw output\n"
+            "  -v<level>           Verbose output (0 to 5, 0=quiet)\n"
+            "  -V                  Output version information and exit\n"
+            "  -t                  Terminate when all clients close\n");
     exit(1);
 }
 
@@ -870,7 +875,7 @@ TimerExpired(void)
 /*
   here is where we would add code to allow control from
   the keyboard.  We would want to read a command and
-  interpret it.  Possibilties:
+  interpret it.  Possibilities:
 
   (a) verbose level setting
   (b) reset time
@@ -1011,11 +1016,19 @@ ServerHalf(FD fd)
 const char *
 ClientName(FD fd)
 {
-    static char name[12];
+    static char name[62];
+    unsigned pos = 0;
+    const char *peer_info;
 
     if (clientNumber <= 1)
-        return ("");
-    snprintf(name, sizeof(name), " %d", FDinfo[fd].ClientNumber);
+        name[0] = '\0';
+    else
+        pos = snprintf(name, sizeof(name), " %d", FDinfo[fd].ClientNumber);
+
+    peer_info = GetPeerInfo(fd);
+    if (peer_info)
+        snprintf(name + pos, sizeof(name) - pos, " (%s)", peer_info);
+
     return (name);
 }
 
